import qrcode

def generate_qr_code(text,filename):
    qr = qrcode.QRCode(
        version=1,
        error_correction=qrcode.constants.ERROR_CORRECT_L,
        box_size=10,
        border=4,
    )
    qr.add_data(text)
    qr.make(fit=True)

    img = qr.make_image(fill_color="black", back_color="white")
    img.save(f"{filename}")




             
     



from setuptools import setup, find_packages

setup(
    name='text_to_qrcode',
    version='0.1',
    packages=find_packages(),
    entry_points={
        'console_scripts': [
            'text_to_qrcode = text_to_qrcode.text_to_qrcode:main'
        ]
    },
    author='Sajal Sisodia',
    author_email='Sajal89304@gmail.com',
    description='A package for calculating factorial.',
    url='https://github.com/Sam-Sisodia/text_to_qQrocde.git',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    install_requires=[
        "qrcode",
    ]
)
